@@ -89,8 +89,8 @@ pub fn alloc_align(offset: usize) -> usize {
 	align(offset, granularity())
 }
 
-pub unsafe fn zero(addr: *mut u8, size: usize) {
-	std::intrinsics::volatile_set_memory(addr, 0, size);
+pub unsafe fn zero<T>(addr: *mut T, count: usize) {
+	std::intrinsics::volatile_set_memory(addr, 0, count);
 }
 
 #[cfg(unix)]
@@ -339,4 +339,32 @@ mod tests {
 
 		unsafe { release(buf, size) }.unwrap();
 	}
+
+	#[cfg(unix)]
+	#[test]
+	fn test_uncommit() {
+		use bulletproof::Bulletproof;
+
+		let size = std::cmp::max(granularity(), 2 * page_size());
+		let bp = unsafe { Bulletproof::new() };
+		let buf = unsafe { allocate(size, Protection::ReadWrite) }.unwrap();
+
+		for i in 0..size {
+			assert_eq!(unsafe { bp.load(buf.add(i)) }, Ok(0));
+			assert_eq!(unsafe { bp.store(buf.add(i), &0x55) }, Ok(()));
+			assert_eq!(unsafe { bp.load(buf.add(i)) }, Ok(0x55));
+		}
+
+		unsafe { uncommit(buf.add(size - page_size()), page_size()) }.unwrap();
+
+		for i in 0 .. size - page_size() {
+			assert_eq!(unsafe { bp.load(buf.add(i)) }, Ok(0x55));
+		}
+
+		for i in size - page_size() + 1 .. size {
+			assert_eq!(unsafe { bp.load(buf.add(i)) }, Err(()));
+		}
+
+		unsafe { release(buf, size - page_size()) }.unwrap();
+	}
 }
